==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/nastaveni/planovanikapacit.php <==
<?php
/**
 * stanislav.elbl, 06.01.2016
 */

namespace RonPortal\Settings;

use Ron\Controls\Preference;

return [
    'caption' => 'Nastaveni_planovani_kapacit',
    'category' => 'nastaveni_sekce_planovani',
    'name'  => 'kapacity',
    'index' => 260,
    'storage' => 'nastaveni',
    'strings' => 'kapacity.ini',
    'items' =>
        [
            // vychozi rezim
            [
                'name'  => 'kapacity_rezim',    'type'  => Preference::COMBOBOX,    'title' => 'Vychozi_rezim_zobrazeni_kapacit',
                'options' => [
                    0 => 'Puvodni_plan', 1 => 'Upraveny_plan', 2 => 'Kombinovany_plan',  3 => 'Kapacity_dle_smen', 4 => 'Prehled_podle_slotu'
                ],
                'defaultValue' => 0
            ],
            // jen s kalendarem podle PK
            [
                'name'  => 'kapacity_jenskalendarem', 'type'  => Preference::CHECKBOX,      'title' => 'Jen_zamestnanci_s_kalendarem_pk',
                'infoText' => 'Jen_zamestnanci_s_kalendarem_pk_info',
                'defaultValue' => 0
            ],
            // vybrane evidencni stavy
            [
                'name'  => 'kapacity_evidencnistavy', 'type'  => Preference::TEXT,          'title' => 'Jen_vybrane_evidencni_stavy',
                'defaultValue' => ''
            ],
            // jen v evidencnim stavu
            [
                'name'  => 'kapacity_jenvevidencnimstavu', 'type'  => Preference::CHECKBOX,    'title' => 'Jen_zamestnanci_v_evidencnim_stavu',
                'infoText' => 'Jen_zamestnanci_v_evidencnim_stavu_info',
                'defaultValue' => 0
            ],
            // zapnuti kontrol planovani (ADS_Agent_CapacityPlanning)
            [
                'name'  => 'kapacity_kontrolovat_podminky', 'type'  => Preference::CHECKBOX,    'title' => 'Kontrolovat_podminky_planovani',
                'infoText' => 'Kontrolovat_podminky_planovani_info',
                'defaultValue' => 0
            ],
            // pujcovani zamestnancu
            [
                'name'  => 'kapacity_cizi', 'type'  => Preference::CHECKBOX,    'title' => 'Povolit_pujcovani_zamestnancu_pk',
                'infoText' => 'Povolit_pujcovani_zamestnancu_pk_info',
                'defaultValue' => 0
            ],
            [
                'name'  => 'kapacity_rozd_dle_prav', 'type'  => Preference::CHECKBOX,    'title' => 'Vyber_rozdelni_pro_prerazeni_dle_prav',
                'infoText' => 'Vyber_rozdelni_pro_prerazeni_dle_prav_info',
                'defaultValue' => 0
            ],
            [
                'name'  => 'kapacity_smenypodlerozdeleni', 'type'  => Preference::CHECKBOX,    'title' => 'Vyber_kalendare_podle_rozdeleni',
                'infoText' => 'Vyber_kalendare_podle_rozdeleni_info',
                'defaultValue' => 0
            ],


            [
                'name'  => 'kapacity_zpusobschvalovani', 'type'  => Preference::CHECKBOX,    'title' => 'Zpusob_schvalovani_kapacit',
                'defaultValue' => 0
            ],

            [
                'name'  => 'kapacity_zakazatsnizitschvaleni', 'type'  => Preference::CHECKBOX,    'title' => 'Zakazat_snizit_schvaleni',
                'defaultValue' => 0
            ],

            // ikony pro rozdeleni
            [
                'name'  => 'kapacity_ikony_rozdeleni', 'type'  => Preference::TEXT,    'title' => 'Typy_rozdelni_pro_ikony_pk',
                'defaultValue' => '',
                'infoText' => 'Typy_rozdelni_pro_ikony_pk_info'
            ],
            // obarveni radku podle rozdeleni
            [
                'name'  => 'kapacity_barvy_rozdeleni', 'type'  => Preference::TEXT,    'title' => 'Typy_rozdelni_pro_obarveni_radku',
                'defaultValue' => '',
                'infoText' => 'Typy_rozdelni_pro_obarveni_radku_info'
            ],

            // planovani podle slotu
            [
                'type'  => Preference::CATEGORY,    'title' => 'Planovani_po_slotech'

            ],
            [
                'name'  => 'kapacity_povolitsloty', 'type'  => Preference::CHECKBOX,        'title' => 'Povolit_planovani_po_slotech',
                'infoText' => 'Povolit_planovani_po_slotech_info',
                'defaultValue' => 0
            ],
            [
                'name'  => 'kapacity_absence_do_slotu', 'type'  => Preference::CHECKBOX,    'title' => 'Absence_planovat_do_slotu',
                'defaultValue' => 0
            ],

            // editace smen pro den kalendare
            [
                'type'  => Preference::CATEGORY,   'title' => 'Nastaveni_planovani_podminek',
            ],
            [
                'name'  => 'planovanipodminek', 'type'  => Preference::CHECKBOX,    'title' => 'Povolit_planovani_podle_podminek',
                'defaultValue' => 0
            ],
            [
                'name'  => 'sablonyprodenkalendare', 'type'  => Preference::CHECKBOX,    'title' => 'Sablony_pro_den_kalendare',
                'defaultValue' => 0,
                'infoText' => 'Sablony_pro_den_kalendare_info'
            ],

            // rozdeleni 1
            [
                'type'  => Preference::CATEGORY,    'title' => 'PK_rozdeleni_1'
            ],

            [
                'name'  => 'kapacity_typrozdeleni',    'type'  => Preference::SQL_COMBOBOX,    'title' => 'Typ_rozdeleni_pk',
                'sql'   => 'SELECT Kod, Popis FROM TypRozdeleni ORDER BY Kod',
                'readOnly' => true
            ],
            [
                'name'  => 'kapacity_automatickyrozdeleni1',    'type'  => Preference::COMBOBOX,    'title' => 'Automaticky_rozdeleni_pk_1',
                'options' => [
                    0 => 'pk_automaticky_r2_nic', 1 => 'pk_automaticky_r2_primarni',    // pouzije stejne texty jako pro rozdeleni 2
                    2 => 'pk_automaticky_r2_prirazene', 3 => 'pk_automaticky_r_editovane'
                ],
                'defaultValue' => '0',
            ],


            // rozdeleni 2
            [
                'type'  => Preference::CATEGORY,    'title' => 'PK_rozdeleni_2'

            ],
            [
                'name'  => 'kapacity_typrozdeleni2',    'type'  => Preference::SQL_COMBOBOX,    'title' => 'Typ_rozdeleni_pk_2',
                'sql'   => 'SELECT Kod, Popis FROM TypRozdeleni ORDER BY Kod',
                'defaultValue' => '',
                'infoText' => 'Typ_rozdeleni_pk_2_info'
            ],
            [
                'name'  => 'kapacity_vyberrozdeleni2', 'type'  => Preference::COMBOBOX,    'title' => 'Vyber_rozdeleni_2_pk',
                'options' => [
                    0 => 'pk_vsechna_rozdeleni_2', 1 => 'pk_vlastni_rozdeleni_2', 2 => 'pk_vlastni_a_podrizena_rozdeleni_2',  3 => 'pk_podrizena_rozdeleni_2'
                ],
                'defaultValue' => '0',
            ],
            [
                'name'  => 'kapacity_automatickyrozdeleni2',    'type'  => Preference::COMBOBOX,    'title' => 'Automaticky_rozdeleni_pk_2',
                'options' => [
                    0 => 'pk_automaticky_r2_nic', 1 => 'pk_automaticky_r2_primarni', 2 => 'pk_automaticky_r2_prirazene'
                ],
                'defaultValue' => '0',
            ],
            // pasivni rezim
            [
                'type'  => Preference::CATEGORY,    'title' => 'Nastaveni_pro_pasivni_rezim'

            ],
            // velikost bunky
            [
                'name'  => 'kapacity_sirka_pasivni', 'type'  => Preference::TEXT,    'title' => 'Velikost_bunky_pasivni_sirka',
                'defaultValue' => ''
            ],
            [
                'name'  => 'kapacity_vyska_pasivni', 'type'  => Preference::TEXT,    'title' => 'Velikost_bunky_pasivni_vyska',
                'defaultValue' => ''
            ],
            [
                'name'  => 'kapacity_sirka_kombi', 'type'  => Preference::TEXT,    'title' => 'Velikost_bunky_kombinovane_sirka',
                'defaultValue' => ''
            ],
            [
                'name'  => 'kapacity_vyska_kombi', 'type'  => Preference::TEXT,    'title' => 'Velikost_bunky_kombinovane_vyska',
                'defaultValue' => ''
            ],
            // aktivni rezim
            [
                'type'  => Preference::CATEGORY,    'title' => 'Nastaveni_pro_aktivni_rezim'

            ],
            // velikost bunky
            [
                'name'  => 'kapacity_sirka', 'type'  => Preference::TEXT,    'title' => 'Velikost_bunky_aktivni_sirka',
                'defaultValue' => ''
            ],
            [
                'name'  => 'kapacity_vyska', 'type'  => Preference::TEXT,    'title' => 'Velikost_bunky_aktivni_vyska',
                'defaultValue' => ''
            ],
            [
                'name'  => 'kapacity_znaku_poznamka', 'type'  => Preference::TEXT,    'title' => 'Pocet_zobrazenych_znaku_poznamka',
                'infoText' => 'Pocet_zobrazenych_znaku_poznamka_info',
                'defaultValue' => ''
            ],
            // editace ve schvalenych dnech
            [
                'name'  => 'editaceschvalenychkapacit', 'type'  => Preference::CHECKBOX,    'title' => 'Povolit_editaci_schvalenych_pk',
                'infoText' => 'Povolit_editaci_schvalenych_pk_info',
                'defaultValue' => 0
            ],
            [
                'name'  => 'kapacity_cizi_zmena', 'type'  => Preference::CHECKBOX,    'title' => 'Povolit_zmenu_rozdeleni_pri_smene',
                'infoText' => 'Povolit_zmenu_rozdeleni_pri_smene_info',
                'defaultValue' => 0
            ],

            [
                'name'  => 'kapacity_cs_soucet', 'type'  => Preference::TEXT,    'title' => 'Casova_slozka_pro_kontrolu_souctu',
                'infoText' => 'Casova_slozka_pro_kontrolu_souctu_info',
                'defaultValue' => ''
            ],

            [
                'name'  => 'kapacity_absencenaradku', 'type'  => Preference::TEXT,    'title' => 'Pocitat_do_souctu_radku_absence',
                'infoText' => 'Pocitat_do_souctu_radku_absence_info',
                'defaultValue' => '*'
            ],
            [
                'name'  => 'kapacity_absencevesloupci', 'type'  => Preference::TEXT,    'title' => 'Pocitat_do_souctu_sloupce_absence',
                'infoText' => 'Pocitat_do_souctu_sloupce_absence_info',
                'defaultValue' => ''
            ],



            // tlacitko prepocet
            [
                'name'  => 'kapacity_tlacitkoprepocet', 'type'  => Preference::COMBOBOX,    'title' => 'tlacitko_prepocet_pk',
                'options' => [
                    0 => 'tlacitko_prepocet_pk_0', 1 => 'tlacitko_prepocet_pk_1',  2 => 'tlacitko_prepocet_pk_2', 3 => 'tlacitko_prepocet_pk_3', 4 => 'tlacitko_prepocet_pk_4'
                ],
                'defaultValue' => 0,
                'infoText' => 'prepocet_pk_info'
            ],
//            [
//                'name'  => 'kapacity_provadetprepocet', 'type'  => Preference::COMBOBOX,    'title' => 'provadet_prepocet_pk',
//                'options' => [
//                    0 => 'prepocet_pk_0', 1 => 'prepocet_pk_1',  2 => 'prepocet_pk_2', // TODO: pridat "doplnit"
//                ],
//                'defaultValue' => 0,
//                'infoText' => 'prepocet_pk_info'
//            ],


            // podrobnosti v bunce
            [
                'name'  => 'kapacity_text', 'type'  => Preference::MEMO,    'title' => 'Podrobnosti_v_bunce_pk', 'infoText' => 'Podrobnosti_v_bunce_pk_info',
                'defaultValue' => ''
            ],

            [
                'name'  => 'kapacity_casoveslozky',     'type'  => Preference::TEXT, 'title' => 'Typy_casovych_slozek_MV_radek',
                'defaultValue' => '',
                'infoText' => 'Typy_casovych_slozek_MV_radek_info'
            ],

            [
                'name'  => 'kapacity_casoveslozky_css', 'type'  => Preference::TEXT, 'title' => 'Typy_casovych_slozek_MV_css',
                'defaultValue' => '',
                'infoText' => 'Typy_casovych_slozek_MV_css_info'
            ],

            [
                'name'  => 'kapacity_casoveslozkyd',    'type'  => Preference::TEXT, 'title' => 'Typy_casovych_slozek_DV_bunka',
                'defaultValue' => '',
                'infoText' => 'Typy_casovych_slozek_DV_bunka_info'
            ],

            [
                'name'  => 'kapacity_paticka',  'type'  => Preference::TEXT,    'title' => 'Paticka_planovani_kapacit',
                'defaultValue' => '',
                'infoText' => 'Paticka_planovani_kapacit_souctu_info'
            ],

            // Nastaveni prebirane z aplikace
            [
                'type'  => Preference::CATEGORY,    'title' => 'PK_nastaveni_z_aplikace'

            ],

            [
                'name'  => 'kapacity_povolitsmenypodledne',  'type'  => Preference::COMBOBOX,    'title' => 'Vyber_smen_pro_planovani',
                'options' => [1 => 'vyber_smen_pk_1', 2 => 'vyber_smen_pk_2', 3 => 'vyber_smen_pk_3'],
                'readOnly' => true
            ],

            [
                'name'  => 'kapacity_rezimuprav', 'type'  => Preference::CHECKBOX,    'title' => 'Povolit_rezim_uprav',
                'readOnly' => true
            ],
            [
                'name'  => 'kapacity_minschvaleniproupravy',  'type'  => Preference::TEXT,    'title' => 'Minimalni_uroven_schvaleni_pro_upravy',
                'readOnly' => true
            ],
//         else if key = 'kapacity_povolitpodrizenarozdeleni' then kapacity_povolitpodrizenarozdeleni := valuestr
//         else if key = 'kapacity_pocitatdnysabsenci' then kapacity_pocitatdnysabsenci := valuestr


        ]
];

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2305_171.zip: ronportal/nastaveni/planovanikapacit.php <==
<?php
/**
 * stanislav.elbl, 06.01.2016
 */

namespace RonPortal\Settings;

use Ron\Controls\Preference;

return [
    'caption' => 'Nastaveni_planovani_kapacit',
    'category' => 'nastaveni_sekce_planovani',
    'name'  => 'kapacity',
    'index' => 260,
    'storage' => 'nastaveni',
    'strings' => 'kapacity.ini',
    'items' =>
        [
            // vychozi rezim
            [
                'name'  => 'kapacity_rezim',    'type'  => Preference::COMBOBOX,    'title' => 'Vychozi_rezim_zobrazeni_kapacit',
                'options' => [
                    0 => 'Puvodni_plan', 1 => 'Upraveny_plan', 2 => 'Kombinovany_plan',  3 => 'Kapacity_dle_smen', 4 => 'Prehled_podle_slotu'
                ],
                'defaultValue' => 0
            ],
            // jen s kalendarem podle PK
            [
                'name'  => 'kapacity_jenskalendarem', 'type'  => Preference::CHECKBOX,      'title' => 'Jen_zamestnanci_s_kalendarem_pk',
                'infoText' => 'Jen_zamestnanci_s_kalendarem_pk_info',
                'defaultValue' => 0
            ],
            // vybrane evidencni stavy
            [
                'name'  => 'kapacity_evidencnistavy', 'type'  => Preference::TEXT,          'title' => 'Jen_vybrane_evidencni_stavy',
                'defaultValue' => ''
            ],
            // jen v evidencnim stavu
            [
                'name'  => 'kapacity_jenvevidencnimstavu', 'type'  => Preference::CHECKBOX,    'title' => 'Jen_zamestnanci_v_evidencnim_stavu',
                'infoText' => 'Jen_zamestnanci_v_evidencnim_stavu_info',
                'defaultValue' => 0
            ],
            // zapnuti kontrol planovani (ADS_Agent_CapacityPlanning)
            [
                'name'  => 'kapacity_kontrolovat_podminky', 'type'  => Preference::CHECKBOX,    'title' => 'Kontrolovat_podminky_planovani',
                'infoText' => 'Kontrolovat_podminky_planovani_info',
                'defaultValue' => 0
            ],
            // pujcovani zamestnancu
            [
                'name'  => 'kapacity_cizi', 'type'  => Preference::CHECKBOX,    'title' => 'Povolit_pujcovani_zamestnancu_pk',
                'infoText' => 'Povolit_pujcovani_zamestnancu_pk_info',
                'defaultValue' => 0
            ],
            [
                'name'  => 'kapacity_rozd_dle_prav', 'type'  => Preference::CHECKBOX,    'title' => 'Vyber_rozdelni_pro_prerazeni_dle_prav',
                'infoText' => 'Vyber_rozdelni_pro_prerazeni_dle_prav_info',
                'defaultValue' => 0
            ],
            [
                'name'  => 'kapacity_smenypodlerozdeleni', 'type'  => Preference::CHECKBOX,    'title' => 'Vyber_kalendare_podle_rozdeleni',
                'infoText' => 'Vyber_kalendare_podle_rozdeleni_info',
                'defaultValue' => 0
            ],


            [
                'name'  => 'kapacity_zpusobschvalovani', 'type'  => Preference::CHECKBOX,    'title' => 'Zpusob_schvalovani_kapacit',
                'defaultValue' => 0
            ],

            [
                'name'  => 'kapacity_zakazatsnizitschvaleni', 'type'  => Preference::CHECKBOX,    'title' => 'Zakazat_snizit_schvaleni',
                'defaultValue' => 0
            ],

            // ikony pro rozdeleni
            [
                'name'  => 'kapacity_ikony_rozdeleni', 'type'  => Preference::TEXT,    'title' => 'Typy_rozdelni_pro_ikony_pk',
                'defaultValue' => '',
                'infoText' => 'Typy_rozdelni_pro_ikony_pk_info'
            ],
            // obarveni radku podle rozdeleni
            [
                'name'  => 'kapacity_barvy_rozdeleni', 'type'  => Preference::TEXT,    'title' => 'Typy_rozdelni_pro_obarveni_radku',
                'defaultValue' => '',
                'infoText' => 'Typy_rozdelni_pro_obarveni_radku_info'
            ],

            // planovani podle slotu
            [
                'type'  => Preference::CATEGORY,    'title' => 'Planovani_po_slotech'

            ],
            [
                'name'  => 'kapacity_povolitsloty', 'type'  => Preference::CHECKBOX,        'title' => 'Povolit_planovani_po_slotech',
                'infoText' => 'Povolit_planovani_po_slotech_info',
                'defaultValue' => 0
            ],
            [
                'name'  => 'kapacity_absence_do_slotu', 'type'  => Preference::CHECKBOX,    'title' => 'Absence_planovat_do_slotu',
                'defaultValue' => 0
            ],

            // editace smen pro den kalendare
            [
                'type'  => Preference::CATEGORY,   'title' => 'Nastaveni_planovani_podminek',
            ],
            [
                'name'  => 'planovanipodminek', 'type'  => Preference::CHECKBOX,    'title' => 'Povolit_planovani_podle_podminek',
                'defaultValue' => 0
            ],
            [
                'name'  => 'sablonyprodenkalendare', 'type'  => Preference::CHECKBOX,    'title' => 'Sablony_pro_den_kalendare',
                'defaultValue' => 0,
                'infoText' => 'Sablony_pro_den_kalendare_info'
            ],

            // rozdeleni 1
            [
                'type'  => Preference::CATEGORY,    'title' => 'PK_rozdeleni_1'
            ],

            [
                'name'  => 'kapacity_typrozdeleni',    'type'  => Preference::SQL_COMBOBOX,    'title' => 'Typ_rozdeleni_pk',
                'sql'   => 'SELECT Kod, Popis FROM TypRozdeleni ORDER BY Kod',
                'readOnly' => true
            ],
            [
                'name'  => 'kapacity_automatickyrozdeleni1',    'type'  => Preference::COMBOBOX,    'title' => 'Automaticky_rozdeleni_pk_1',
                'options' => [
                    0 => 'pk_automaticky_r2_nic', 1 => 'pk_automaticky_r2_primarni',    // pouzije stejne texty jako pro rozdeleni 2
                    2 => 'pk_automaticky_r2_prirazene', 3 => 'pk_automaticky_r_editovane'
                ],
                'defaultValue' => '0',
            ],


            // rozdeleni 2
            [
                'type'  => Preference::CATEGORY,    'title' => 'PK_rozdeleni_2'

            ],
            [
                'name'  => 'kapacity_typrozdeleni2',    'type'  => Preference::SQL_COMBOBOX,    'title' => 'Typ_rozdeleni_pk_2',
                'sql'   => 'SELECT Kod, Popis FROM TypRozdeleni ORDER BY Kod',
                'defaultValue' => '',
                'infoText' => 'Typ_rozdeleni_pk_2_info'
            ],
            [
                'name'  => 'kapacity_vyberrozdeleni2', 'type'  => Preference::COMBOBOX,    'title' => 'Vyber_rozdeleni_2_pk',
                'options' => [
                    0 => 'pk_vsechna_rozdeleni_2', 1 => 'pk_vlastni_rozdeleni_2', 2 => 'pk_vlastni_a_podrizena_rozdeleni_2',  3 => 'pk_podrizena_rozdeleni_2'
                ],
                'defaultValue' => '0',
            ],
            [
                'name'  => 'kapacity_automatickyrozdeleni2',    'type'  => Preference::COMBOBOX,    'title' => 'Automaticky_rozdeleni_pk_2',
                'options' => [
                    0 => 'pk_automaticky_r2_nic', 1 => 'pk_automaticky_r2_primarni', 2 => 'pk_automaticky_r2_prirazene'
                ],
                'defaultValue' => '0',
            ],
            // pasivni rezim
            [
                'type'  => Preference::CATEGORY,    'title' => 'Nastaveni_pro_pasivni_rezim'

            ],
            // velikost bunky
            [
                'name'  => 'kapacity_sirka_pasivni', 'type'  => Preference::TEXT,    'title' => 'Velikost_bunky_pasivni_sirka',
                'defaultValue' => ''
            ],
            [
                'name'  => 'kapacity_vyska_pasivni', 'type'  => Preference::TEXT,    'title' => 'Velikost_bunky_pasivni_vyska',
                'defaultValue' => ''
            ],
            [
                'name'  => 'kapacity_sirka_kombi', 'type'  => Preference::TEXT,    'title' => 'Velikost_bunky_kombinovane_sirka',
                'defaultValue' => ''
            ],
            [
                'name'  => 'kapacity_vyska_kombi', 'type'  => Preference::TEXT,    'title' => 'Velikost_bunky_kombinovane_vyska',
                'defaultValue' => ''
            ],
            // aktivni rezim -----------------------------------------------------------------
            [
                'type'  => Preference::CATEGORY,    'title' => 'Nastaveni_pro_aktivni_rezim'

            ],
            [
                'name'  => 'kapacity_aktivni_jen_editovatelne', 'type'  => Preference::CHECKBOX,    'title' => 'Zobrazit_jen_editovatelne_pk',
                'defaultValue' => 0
            ],
            // velikost bunky
            [
                'name'  => 'kapacity_sirka', 'type'  => Preference::TEXT,    'title' => 'Velikost_bunky_aktivni_sirka',
                'defaultValue' => ''
            ],
            [
                'name'  => 'kapacity_vyska', 'type'  => Preference::TEXT,    'title' => 'Velikost_bunky_aktivni_vyska',
                'defaultValue' => ''
            ],
            [
                'name'  => 'kapacity_znaku_poznamka', 'type'  => Preference::TEXT,    'title' => 'Pocet_zobrazenych_znaku_poznamka',
                'infoText' => 'Pocet_zobrazenych_znaku_poznamka_info',
                'defaultValue' => ''
            ],
            // editace ve schvalenych dnech
            [
                'name'  => 'editaceschvalenychkapacit', 'type'  => Preference::CHECKBOX,    'title' => 'Povolit_editaci_schvalenych_pk',
                'infoText' => 'Povolit_editaci_schvalenych_pk_info',
                'defaultValue' => 0
            ],
            [
                'name'  => 'kapacity_cizi_zmena', 'type'  => Preference::CHECKBOX,    'title' => 'Povolit_zmenu_rozdeleni_pri_smene',
                'infoText' => 'Povolit_zmenu_rozdeleni_pri_smene_info',
                'defaultValue' => 0
            ],

            [
                'name'  => 'kapacity_cs_soucet', 'type'  => Preference::TEXT,    'title' => 'Casova_slozka_pro_kontrolu_souctu',
                'infoText' => 'Casova_slozka_pro_kontrolu_souctu_info',
                'defaultValue' => ''
            ],

            [
                'name'  => 'kapacity_absencenaradku', 'type'  => Preference::TEXT,    'title' => 'Pocitat_do_souctu_radku_absence',
                'infoText' => 'Pocitat_do_souctu_radku_absence_info',
                'defaultValue' => '*'
            ],
            [
                'name'  => 'kapacity_absencevesloupci', 'type'  => Preference::TEXT,    'title' => 'Pocitat_do_souctu_sloupce_absence',
                'infoText' => 'Pocitat_do_souctu_sloupce_absence_info',
                'defaultValue' => ''
            ],



            // tlacitko prepocet
            [
                'name'  => 'kapacity_tlacitkoprepocet', 'type'  => Preference::COMBOBOX,    'title' => 'tlacitko_prepocet_pk',
                'options' => [
                    0 => 'tlacitko_prepocet_pk_0', 1 => 'tlacitko_prepocet_pk_1',  2 => 'tlacitko_prepocet_pk_2', 3 => 'tlacitko_prepocet_pk_3',
                    4 => 'tlacitko_prepocet_pk_4', 5 => 'tlacitko_prepocet_pk_5'
                ],
                'defaultValue' => 0,
                'infoText' => 'prepocet_pk_info'
            ],
//            [
//                'name'  => 'kapacity_provadetprepocet', 'type'  => Preference::COMBOBOX,    'title' => 'provadet_prepocet_pk',
//                'options' => [
//                    0 => 'prepocet_pk_0', 1 => 'prepocet_pk_1',  2 => 'prepocet_pk_2', // TODO: pridat "doplnit"
//                ],
//                'defaultValue' => 0,
//                'infoText' => 'prepocet_pk_info'
//            ],


            // podrobnosti v bunce
            [
                'name'  => 'kapacity_text', 'type'  => Preference::MEMO,    'title' => 'Podrobnosti_v_bunce_pk', 'infoText' => 'Podrobnosti_v_bunce_pk_info',
                'defaultValue' => ''
            ],

            [
                'name'  => 'kapacity_casoveslozky',     'type'  => Preference::TEXT, 'title' => 'Typy_casovych_slozek_MV_radek',
                'defaultValue' => '',
                'infoText' => 'Typy_casovych_slozek_MV_radek_info'
            ],

            [
                'name'  => 'kapacity_casoveslozky_css', 'type'  => Preference::TEXT, 'title' => 'Typy_casovych_slozek_MV_css',
                'defaultValue' => '',
                'infoText' => 'Typy_casovych_slozek_MV_css_info'
            ],

            [
                'name'  => 'kapacity_casoveslozkyd',    'type'  => Preference::TEXT, 'title' => 'Typy_casovych_slozek_DV_bunka',
                'defaultValue' => '',
                'infoText' => 'Typy_casovych_slozek_DV_bunka_info'
            ],

            [
                'name'  => 'kapacity_paticka',  'type'  => Preference::TEXT,    'title' => 'Paticka_planovani_kapacit',
                'defaultValue' => '',
                'infoText' => 'Paticka_planovani_kapacit_souctu_info'
            ],

            // Nastaveni prebirane z aplikace
            [
                'type'  => Preference::CATEGORY,    'title' => 'PK_nastaveni_z_aplikace'

            ],

            [
                'name'  => 'kapacity_povolitsmenypodledne',  'type'  => Preference::COMBOBOX,    'title' => 'Vyber_smen_pro_planovani',
                'options' => [1 => 'vyber_smen_pk_1', 2 => 'vyber_smen_pk_2', 3 => 'vyber_smen_pk_3'],
                'readOnly' => true
            ],

            [
                'name'  => 'kapacity_rezimuprav', 'type'  => Preference::CHECKBOX,    'title' => 'Povolit_rezim_uprav',
                'readOnly' => true
            ],
            [
                'name'  => 'kapacity_minschvaleniproupravy',  'type'  => Preference::TEXT,    'title' => 'Minimalni_uroven_schvaleni_pro_upravy',
                'readOnly' => true
            ],
//         else if key = 'kapacity_povolitpodrizenarozdeleni' then kapacity_povolitpodrizenarozdeleni := valuestr
//         else if key = 'kapacity_pocitatdnysabsenci' then kapacity_pocitatdnysabsenci := valuestr


        ]
];
